==> jc-1.4.0.tar.gz: soot/jimple/internal/JNewExpr.h <==
// public class soot.jimple.internal.JNewExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6b55caa091ae3a14 soot_jimple_internal_AbstractNewExpr
// @dep_class 9660e926ad29078a soot_jimple_internal_JNewExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractNewExpr

#include "soot/jimple/internal/AbstractNewExpr.h"

#ifndef _JC_soot_jimple_internal_JNewExpr_H_
#define _JC_soot_jimple_internal_JNewExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_RefType$object;
struct _jc_soot_jimple_JimpleToBafContext$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JNewExpr$sub_refs	_jc_soot_jimple_internal_JNewExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JNewExpr$sub_nonrefs	_jc_soot_jimple_internal_JNewExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JNewExpr$refs	_jc_soot_jimple_internal_JNewExpr$refs;
typedef struct _jc_soot_jimple_internal_JNewExpr$nonrefs	_jc_soot_jimple_internal_JNewExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JNewExpr$object	_jc_soot_jimple_internal_JNewExpr$object;

typedef const struct _jc_soot_jimple_internal_JNewExpr$vmethods	_jc_soot_jimple_internal_JNewExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JNewExpr$vtable	_jc_soot_jimple_internal_JNewExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JNewExpr$vtype	_jc_soot_jimple_internal_JNewExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JNewExpr$method$_init$b4480ebfa3c48018(_jc_env *, struct _jc_soot_jimple_internal_JNewExpr$object *, struct _jc_soot_RefType$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JNewExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JNewExpr$object *);
extern void _jc_soot_jimple_internal_JNewExpr$method$convertToBaf$0357e46cf55b475a(_jc_env *, struct _jc_soot_jimple_internal_JNewExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JNewExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_JNewExpr$method_info$convertToBaf$0357e46cf55b475a;

// Virtual methods structure
struct _jc_soot_jimple_internal_JNewExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JNewExpr$object *);
	void	(*convertToBaf$0357e46cf55b475a)(_jc_env *, struct _jc_soot_jimple_internal_JNewExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_internal_JNewExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractNewExpr$vmethods	soot_jimple_internal_AbstractNewExpr;
	_jc_soot_jimple_internal_JNewExpr$vmethods	soot_jimple_internal_JNewExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JNewExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JNewExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JNewExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JNewExpr$refs {
    _jc_soot_jimple_internal_JNewExpr$sub_refs	soot_jimple_internal_JNewExpr;
    _jc_soot_jimple_internal_AbstractNewExpr$sub_refs	soot_jimple_internal_AbstractNewExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JNewExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JNewExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractNewExpr$sub_nonrefs	soot_jimple_internal_AbstractNewExpr;
    _jc_soot_jimple_internal_JNewExpr$sub_nonrefs	soot_jimple_internal_JNewExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JNewExpr$object {
	_jc_soot_jimple_internal_JNewExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JNewExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JNewExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JNewExpr$vtype _jc_soot_jimple_internal_JNewExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JNewExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JNewExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JNewExpr_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/JNewExpr.h <==
// public class soot.jimple.internal.JNewExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6b55caa091ae3a14 soot_jimple_internal_AbstractNewExpr
// @dep_class 9660e926ad29078a soot_jimple_internal_JNewExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractNewExpr

#include "soot/jimple/internal/AbstractNewExpr.h"

#ifndef _JC_soot_jimple_internal_JNewExpr_H_
#define _JC_soot_jimple_internal_JNewExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_RefType$object;
struct _jc_soot_jimple_JimpleToBafContext$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JNewExpr$sub_refs	_jc_soot_jimple_internal_JNewExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JNewExpr$sub_nonrefs	_jc_soot_jimple_internal_JNewExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JNewExpr$refs	_jc_soot_jimple_internal_JNewExpr$refs;
typedef struct _jc_soot_jimple_internal_JNewExpr$nonrefs	_jc_soot_jimple_internal_JNewExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JNewExpr$object	_jc_soot_jimple_internal_JNewExpr$object;

typedef const struct _jc_soot_jimple_internal_JNewExpr$vmethods	_jc_soot_jimple_internal_JNewExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JNewExpr$vtable	_jc_soot_jimple_internal_JNewExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JNewExpr$vtype	_jc_soot_jimple_internal_JNewExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JNewExpr$method$_init$b4480ebfa3c48018(_jc_env *, struct _jc_soot_jimple_internal_JNewExpr$object *, struct _jc_soot_RefType$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JNewExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JNewExpr$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_internal_JNewExpr$method$convertToBaf$0357e46cf55b475a(_jc_env *, struct _jc_soot_jimple_internal_JNewExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JNewExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_JNewExpr$method_info$convertToBaf$0357e46cf55b475a;

// Virtual methods structure
struct _jc_soot_jimple_internal_JNewExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JNewExpr$object *) _JC_JCNI_ATTR;
	void	(*convertToBaf$0357e46cf55b475a)(_jc_env *, struct _jc_soot_jimple_internal_JNewExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_JNewExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractNewExpr$vmethods	soot_jimple_internal_AbstractNewExpr;
	_jc_soot_jimple_internal_JNewExpr$vmethods	soot_jimple_internal_JNewExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JNewExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JNewExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JNewExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JNewExpr$refs {
    _jc_soot_jimple_internal_JNewExpr$sub_refs	soot_jimple_internal_JNewExpr;
    _jc_soot_jimple_internal_AbstractNewExpr$sub_refs	soot_jimple_internal_AbstractNewExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JNewExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JNewExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractNewExpr$sub_nonrefs	soot_jimple_internal_AbstractNewExpr;
    _jc_soot_jimple_internal_JNewExpr$sub_nonrefs	soot_jimple_internal_JNewExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JNewExpr$object {
	_jc_soot_jimple_internal_JNewExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JNewExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JNewExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JNewExpr$vtype _jc_soot_jimple_internal_JNewExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JNewExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JNewExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JNewExpr_H_ */
